@@ -21,7 +21,6 @@ class CMSSatchmoProductPlugin(CMSPluginBase):
 	fields = ['product', 'title', 'style',]
 
 	def render(self, context, instance, placeholder):
-
 		context.update({
 			'instance': instance,
 			'placeholder': placeholder,
@@ -74,7 +73,7 @@ class CMSSatchmoCategoryPlugin(CMSPluginBase):
 	fields = ['category', 'title', 'style',]
 
 	def render(self, context, instance, placeholder):
-		category = Category.objects.get(id=instance.category_id)
+#		category = Category.objects.get(id=instance.category_id)
 
 		context.update({
 			'instance': instance,
